@@ -10,7 +10,7 @@ use rdkafka::error::KafkaError;
 use rdkafka::message::BorrowedMessage;
 use std::sync::Arc;
 use tokio::sync::oneshot;
-use tracing::{info, instrument, trace_span, warn, Instrument};
+use tracing::{info, info_span, instrument, warn, Instrument};
 
 /// Long-living container for Kafka consuming thread
 #[derive(Clone)]
@@ -29,18 +29,18 @@ impl std::fmt::Debug for KafkaConsumerThreadController {
 impl KafkaConsumerThreadController {
     pub fn new(thread_name: &str, stream_consumer: StreamConsumer) -> KafkaConsumerThreadController {
         KafkaConsumerThreadController {
-            thread_name: thread_name.to_string(),
+            thread_name: thread_name.to_owned(),
             thread_handler: Arc::new(Mutex::new(None)),
             stream_consumer: Arc::new(Mutex::new(stream_consumer)),
         }
     }
 
-    #[instrument(skip(self, processor))]
+    #[instrument(skip_all, fields(thread_name=?self.thread_name))]
     pub fn start<TProcessor>(&self, processor: TProcessor)
     where
         TProcessor: 'static + Fn(Result<BorrowedMessage<'_>, KafkaError>) -> Result<KafkaConsumingStatus, KafkaConsumingError> + Send,
     {
-        info!(action = "start", thread_name = ?self.thread_name);
+        info!(action = "start");
         let (shutdown_trigger, shutdown_tripwire) = oneshot::channel();
 
         let stream_consumer = self.stream_consumer.clone();
@@ -53,26 +53,33 @@ impl KafkaConsumerThreadController {
                 let counter = meter.u64_counter("consume").with_description("Number of consumed events").init();
                 let mut message_stream = stream.take_until(shutdown_tripwire);
                 info!(action = "started");
-                while let Some(message) = message_stream.next().await {
-                    match processor(message) {
-                        Ok(_) => counter.add(1, &[KeyValue::new("status", "ok"), KeyValue::new("thread_name", thread_name.clone())]),
-                        Err(error) => {
-                            warn!(action = "error", error = ?error);
-                            counter.add(1, &[KeyValue::new("status", "error"), KeyValue::new("thread_name", thread_name.clone())]);
+                loop {
+                    match message_stream.next().await {
+                        Some(message) => {
+                            match processor(message) {
+                                Ok(_) => counter.add(1, &[KeyValue::new("status", "ok"), KeyValue::new("thread_name", thread_name.clone())]),
+                                Err(error) => {
+                                    warn!(action = "error", error = ?error);
+                                    counter.add(1, &[KeyValue::new("status", "error"), KeyValue::new("thread_name", thread_name.clone())]);
+                                }
+                            };
                         }
-                    };
+                        None => {
+                            info!(action = "stopped");
+                            break;
+                        }
+                    }
                 }
-                info!(action = "stopped");
                 Ok(())
             }
         }
-        .instrument(trace_span!(parent: None, "consumers", thread_name = ?self.thread_name));
+        .instrument(info_span!(parent: None, "consumer", thread_name = ?self.thread_name));
         *self.thread_handler.lock() = Some(ThreadHandler::new(tokio::spawn(stream_processor), shutdown_trigger));
     }
 
     #[instrument(skip(self))]
-    pub fn commit(&self) -> SummaResult<()> {
-        info!(action = "commit_offsets", thread_name = ?self.thread_name);
+    pub fn commit_offsets(&self) -> SummaResult<()> {
+        info!(action = "commit_consumer_state");
         let result = self.stream_consumer.lock().commit_consumer_state(CommitMode::Sync);
         match result {
             Err(rdkafka::error::KafkaError::ConsumerCommit(rdkafka::error::RDKafkaErrorCode::NoOffset)) => Ok(()),
