@@ -1,35 +1,37 @@
-use std::convert::From;
+use std::convert::{From, Infallible};
 use std::path::PathBuf;
 use tracing::warn;
 
 #[derive(thiserror::Error, Debug)]
-pub enum BadRequestError {
+pub enum ValidationError {
     #[error("aliased_error: {0}")]
     AliasedError(String),
+    #[error("empty_argument: {0}")]
+    EmptyArgument(String),
     #[error("existing_config_error: {0}")]
     ExistingConfigError(PathBuf),
     #[error("existing_consumers_error: {0}")]
     ExistingConsumersError(String),
-    #[error("not_found_error: {0}")]
-    NotFoundError(String),
-    #[error("utf8_error: {0}")]
-    Utf8Error(std::str::Utf8Error),
-}
-
-#[derive(thiserror::Error, Debug)]
-pub enum ValidationError {
     #[error("existing_consumer_error: {0}")]
     ExistingConsumerError(String),
     #[error("existing_path_error: {0}")]
-    ExistingPathError(String),
+    ExistingPathError(PathBuf),
     #[error("invalid_memory_error: {0}")]
     InvalidMemoryError(u64),
     #[error("invalid_threads_number_error: {0}")]
     InvalidThreadsNumberError(u64),
+    #[error("missing_consumer_error: {0}")]
+    MissingConsumerError(String),
+    #[error("missing_index_error: {0}")]
+    MissingIndexError(String),
     #[error("missing_default_field_error: {0}")]
     MissingDefaultField(String),
+    #[error("missing_path_error: {0}")]
+    MissingPathError(String),
     #[error("missing_primary_key_error: {0:?}")]
     MissingPrimaryKeyError(Option<String>),
+    #[error("utf8_error: {0}")]
+    Utf8Error(std::str::Utf8Error),
 }
 
 #[derive(thiserror::Error, Debug)]
@@ -38,14 +40,14 @@ pub enum Error {
     AddrParseError(std::net::AddrParseError),
     #[error("arc_index_writer_holder_leaked_error")]
     ArcIndexWriterHolderLeakedError,
-    #[error("{0}")]
-    BadRequestError(BadRequestError),
     #[error("canceled_error")]
     CanceledError,
     #[error("config_error: {0}")]
     ConfigError(config::ConfigError),
     #[error("hyper_error: {0}")]
     HyperError(hyper::Error),
+    #[error("infallible")]
+    Infallible,
     #[error("internal_error")]
     InternalError,
     #[error("{0:?}")]
@@ -66,6 +68,8 @@ pub enum Error {
     TonicError(tonic::transport::Error),
     #[error("transition_state_error")]
     TransitionStateError,
+    #[error("unbound_document_error")]
+    UnboundDocumentError,
     #[error("unknown_directory_error: {0}")]
     UnknownDirectoryError(String),
     #[error("utf8_error: {0}")]
@@ -82,12 +86,6 @@ impl From<ValidationError> for Error {
     }
 }
 
-impl From<BadRequestError> for Error {
-    fn from(error: BadRequestError) -> Self {
-        Error::BadRequestError(error)
-    }
-}
-
 impl From<config::ConfigError> for Error {
     fn from(error: config::ConfigError) -> Self {
         Error::ConfigError(error)
@@ -126,7 +124,7 @@ impl From<std::net::AddrParseError> for Error {
 
 impl From<std::str::Utf8Error> for Error {
     fn from(error: std::str::Utf8Error) -> Self {
-        Error::BadRequestError(BadRequestError::Utf8Error(error))
+        Error::ValidationError(ValidationError::Utf8Error(error))
     }
 }
 
@@ -154,6 +152,12 @@ impl From<tonic::transport::Error> for Error {
     }
 }
 
+impl From<Infallible> for Error {
+    fn from(_: Infallible) -> Self {
+        Error::Infallible
+    }
+}
+
 impl From<Error> for tonic::Status {
     fn from(error: Error) -> Self {
         warn!(action = "error", error = ?error);
@@ -164,8 +168,8 @@ impl From<Error> for tonic::Status {
                     _ => tonic::Code::Internal,
                 },
                 Error::TantivyError(_) => tonic::Code::InvalidArgument,
-                Error::BadRequestError(BadRequestError::NotFoundError(_)) => tonic::Code::NotFound,
-                Error::BadRequestError(_) => tonic::Code::InvalidArgument,
+                Error::ValidationError(ValidationError::MissingConsumerError(_)) | Error::ValidationError(ValidationError::MissingIndexError(_)) => tonic::Code::NotFound,
+                Error::ValidationError(_) => tonic::Code::InvalidArgument,
                 _ => tonic::Code::Internal,
             },
             format!("{}", error),
@@ -173,4 +177,10 @@ impl From<Error> for tonic::Status {
     }
 }
 
+impl From<ValidationError> for tonic::Status {
+    fn from(error: ValidationError) -> Self {
+        tonic::Status::from(Error::ValidationError(error))
+    }
+}
+
 pub type SummaResult<T> = Result<T, Error>;
