@@ -1,4 +1,4 @@
-use crate::configurator::configs::KafkaConsumerConfig;
+use crate::configs::KafkaConsumerConfig;
 use crate::errors::SummaResult;
 use crate::proto;
 
@@ -10,13 +10,7 @@ pub struct CreateConsumerRequest {
 
 impl CreateConsumerRequest {
     pub fn from_proto(proto_request: &proto::CreateConsumerRequest) -> SummaResult<CreateConsumerRequest> {
-        let consumer_config = KafkaConsumerConfig::new(
-            &proto_request.bootstrap_servers,
-            &proto_request.group_id,
-            &proto_request.index_name,
-            proto_request.threads,
-            &proto_request.topics,
-        )?;
+        let consumer_config = KafkaConsumerConfig::new(&proto_request.bootstrap_servers, &proto_request.group_id, proto_request.threads, &proto_request.topics)?;
         Ok(CreateConsumerRequest {
             consumer_name: proto_request.consumer_name.clone(),
             consumer_config,
