@@ -2,11 +2,12 @@
 
 mod default_tokenizers;
 mod index_holder;
-pub(crate) mod index_layout;
 mod index_updater;
 mod index_writer_holder;
 mod stop_words;
+mod summa_document;
 mod summa_tokenizer;
 
 pub(crate) use index_holder::IndexHolder;
 pub(crate) use index_updater::IndexUpdater;
+pub use summa_document::SummaDocument;
